@@ -50,3 +50,12 @@
 
 // Specify if you are using Linux (assumed with egcs)
 #undef USING_LINUX
+
+// Specify if you have CppUnit installed
+#undef HAS_CPPUNIT
+
+// Specify if you have abs defined for the Complex type
+#undef HAS_COMPLEX_ABS
+
+// Specify if you have conf defined for the Complex type
+#undef HAS_COMPLEX_CONJ
